==> haskell-linear-1.23.2-13-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.2
visibility:           public
id:                   linear-1.23.2-2ak8HHx9jLDJ1Mf9BcF2IF
key:                  linear-1.23.2-2ak8HHx9jLDJ1Mf9BcF2IF
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  95b33c6b6cdda122bd86a0e5cb904afd
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.2-2ak8HHx9jLDJ1Mf9BcF2IF
depends:
    adjunctions-4.4.3-14AEBk5ouds9bnE5dX858g base-4.17.2.1
    base-orphans-0.9.3-3dK3MkfeKl7C1xrohtgqoZ binary-0.8.9.1
    bytes-0.17.4-CudYfXVsSRCHNihm5u4urZ
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    deepseq-1.4.8.0 distributive-0.6.2.1-FzfO5ELY1vT1dz65JdAIDy
    ghc-prim-0.9.1 hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    indexed-traversable-0.1.4-EeVo0prc4Ve5Oh8yIcLoq0
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    random-1.2.1.3-KpmZVmsijPULH6l5PrmXSD
    reflection-2.1.9-E7hB6KmEkOQ92strb8osnl
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-1.23.2-36-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.2
visibility:           public
id:                   linear-1.23.2-3WqJLVjFKpmKGLRxCkhseM
key:                  linear-1.23.2-3WqJLVjFKpmKGLRxCkhseM
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  73346e9581756fdd9cc09584b2fca9a2
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.2-3WqJLVjFKpmKGLRxCkhseM
depends:
    adjunctions-4.4.3-7kmEHvYQQopJuNQHCsXJSB base-4.17.2.1
    base-orphans-0.9.3-HOf1XWEi853HRMMLyvb6TR binary-0.8.9.1
    bytes-0.17.4-AujZYOrYrVrI3Mxo1Blpde
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    deepseq-1.4.8.0 distributive-0.6.2.1-3469zRFAXaLLtl1TZCSnJt
    ghc-prim-0.9.1 hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    indexed-traversable-0.1.4-KvS9wRlCKDWFRGYTEgz6lC
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    reflection-2.1.9-1SRzj82e1StE0xJDK4bUO2
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
